PAWpySeed: pawpyseed.core.noncollinear.NCLWavefunction Class Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Member Functions | Static Public Member Functions | Public Attributes | List of all members
pawpyseed.core.noncollinear.NCLWavefunction Class Reference
Inheritance diagram for pawpyseed.core.noncollinear.NCLWavefunction:
[legend]
Collaboration diagram for pawpyseed.core.noncollinear.NCLWavefunction:
[legend]

## Public Member Functions
def | __init__ (self, struct, pwf, cr, dim, symprec=1e-4, setup_projectors=False)
def | desymmetrized_copy (self, allkpts=None, weights=None)
def | write_state_realspace (self, b, k, s, fileprefix="", dim=None, scale=1, remove_phase=False)
def | write_density_realspace (self, filename="PYAECCAR", dim=None, scale=1)
Public Member Functions inherited from pawpyseed.core.wavefunction.Wavefunction
def | __init__ (self, struct, pwf, cr, dim, symprec=1e-4, setup_projectors=False)
def | update_dim (self, dim)
def | desymmetrized_copy (self, allkpts=None, weights=None)
def | check_c_projectors (self)
def | get_state_realspace (self, b, k, s, dim=None, remove_phase=False)
def | get_state_realspace_density (self, b, k, s, dim=None)
def | get_realspace_density (self, dim=None, bands=None)
def | write_state_realspace (self, b, k, s, fileprefix="", dim=None, scale=1, remove_phase=False)
def | write_density_realspace (self, filename="PYAECCAR", dim=None, scale=1, bands=None)
def | get_nosym_kpoints (self, init_kpts=None, symprec=None, gen_trsym=True, fil_trsym=True)
def | get_kpt_mapping (self, allkpts, symprec=None, gen_trsym=True)

## Static Public Member Functions
def | from_files (struct="CONTCAR", wavecar="WAVECAR", cr="POTCAR", vr="vasprun.xml", setup_projectors=False)
def | from_directory (path, setup_projectors=False)
Static Public Member Functions inherited from pawpyseed.core.wavefunction.Wavefunction
def | from_files (struct="CONTCAR", wavecar="WAVECAR", cr="POTCAR", vr="vasprun.xml", setup_projectors=False)
def | from_directory (path, setup_projectors=False)
def | from_atomate_directory (path, setup_projectors=False)

## Public Attributes
| band_props
| structure
| cr
| dim
Public Attributes inherited from pawpyseed.core.wavefunction.Wavefunction
| band_props
| structure
| symprec
| cr
| dim
| num_sites
| num_elems

## Constructor & Destructor Documentation

def pawpyseed.core.noncollinear.NCLWavefunction.__init__ | ( |  | self,
|  |  | struct,
|  |  | pwf,
|  |  | cr,
|  |  | dim,
|  |  | symprec = `1e-4`,
|  |  | setup_projectors = `False`
| ) |  |

    Arguments:
        struct (pymatgen.core.Structure): structure that the wavefunction describes
        pwf (pawpyc.PWFPointer): holder class for pswf_t and k-points/k-point weights
        cr (CoreRegion): Contains the pseudopotentials, with projectors and
    partials waves, for the structure
        dim (pymatgen.io.vasp.outputs.Outcar OR np.ndarry OR list of length 3):
    Outcar object for reading ngf or the dimensions NG* of the FFT grid
        setup_projectors (bool, False): Whether to set up the core region
    components of the wavefunctions. Pawpyseed will set up the projectors
    automatically when they are first needed, so this generally
    can be left as False.
    Returns:
        Wavefunction object

## Member Function Documentation

def pawpyseed.core.noncollinear.NCLWavefunction.desymmetrized_copy | ( |  | self,
|  |  | allkpts = `None`,
|  |  | weights = `None`
| ) |  |

def pawpyseed.core.noncollinear.NCLWavefunction.from_directory | ( |  | path,
|  |  | setup_projectors = `False`
| ) |  |
| static

    Assumes VASP output has the default filenames and is located
    in the directory specificed by path.

    Arguments:
        path (str): VASP output directory
        setup_projectors (bool, False): Whether to set up the core region
    components of the wavefunctions. Pawpyseed will set up the projectors
    automatically when they are first needed, so this generally
    can be left as False.

    Returns:
        Wavefunction object

def pawpyseed.core.noncollinear.NCLWavefunction.from_files | ( |  | struct = `"CONTCAR"`,
|  |  | wavecar = `"WAVECAR"`,
|  |  | cr = `"POTCAR"`,
|  |  | vr = `"vasprun.xml"`,
|  |  | setup_projectors = `False`
| ) |  |
| static

    Construct a Wavefunction object from file paths.

    Arguments:
        struct (str): VASP POSCAR or CONTCAR file path
        wavecar (str): VASP WAVECAR file path
        cr (str): VASP POTCAR file path
        vr (str): VASP vasprun file path
        outcar (str): VASP OUTCAR file path
        setup_projectors (bool, False): Whether to set up the core region
    components of the wavefunctions. Pawpyseed will set up the projectors
    automatically when they are first needed, so this generally
    can be left as False.

    Returns:
        Wavefunction object

def pawpyseed.core.noncollinear.NCLWavefunction.write_density_realspace | ( |  | self,
|  |  | filename = `"PYAECCAR"`,
|  |  | dim = `None`,
|  |  | scale = `1`
| ) |  |

    Writes the real and imaginary parts of a given band to two files,
    prefixed by fileprefix

    Args:
        b (int): band number (0-indexed!)
        k (int): kpoint number (0-indexed!)
        s (int): spin number (0-indexed!)
        fileprefix (string, ""): first part of the file name
        dim (numpy array of 3 ints, None): dimensions of the FFT grid
        scale (scalar, 1): number to multiply the realspace wavefunction by.
    For example, VASP multiplies charge density by the volume
    of the structure.
    Returns:
        A 3D array (indexed by x,y,z where x,y,z are fractional coordinates)
    with complex double values for the realspace wavefunction
        The charge density is written with z the slow index.

def pawpyseed.core.noncollinear.NCLWavefunction.write_state_realspace | ( |  | self,
|  |  | b,
|  |  | k,
|  |  | s,
|  |  | fileprefix = `""`,
|  |  | dim = `None`,
|  |  | scale = `1`,
|  |  | remove_phase = `False`
| ) |  |

    Writes the real and imaginary parts of a given band to two files,
    prefixed by fileprefix

    Args:
        b (int): band number (0-indexed!)
        k (int): kpoint number (0-indexed!)
        s (int): spin number (0-indexed!)
        fileprefix (string, ""): first part of the file name
        dim (numpy array of 3 ints, None): dimensions of the FFT grid
        scale (scalar, 1): number to multiply the realspace wavefunction by.
    For example, VASP multiplies charge density by the volume
    of the structure.
        remove_phase (False): If True, removes the e^(ikr) phase
    from the wavefunction (this does not necessarily mean
    the wavefunction is real). This is useful if you want
    to visualize the wavefunction because the e^(ikr) phase
    makes the wavefunction non-periodic
    Returns:
        A 3D array (indexed by x,y,z where x,y,z are fractional coordinates)
    with complex double values for the realspace wavefunction
        The wavefunction is written in two files with z the slow index.

## Member Data Documentation

pawpyseed.core.noncollinear.NCLWavefunction.band_props

pawpyseed.core.noncollinear.NCLWavefunction.cr

pawpyseed.core.noncollinear.NCLWavefunction.dim

pawpyseed.core.noncollinear.NCLWavefunction.structure

The documentation for this class was generated from the following file:

- /home/kyle/Research/projects/pawpyseed/pawpyseed/core/noncollinear.py